All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH] Add new location of Linux direct-map to the places to look for writable mappings
@ 2008-09-12 15:38 George Dunlap
  2008-09-12 15:57 ` Daniel Magenheimer
  2008-09-12 23:49 ` [PATCH] Add new location of Linux direct-map to the places " Jeremy Fitzhardinge
  0 siblings, 2 replies; 7+ messages in thread
From: George Dunlap @ 2008-09-12 15:38 UTC (permalink / raw)
  To: xen-devel mailing list

Add new location of Linux direct-map to the places to look for
writable mappings.

Signed-off-by: George Dunlap <george.dunlap@eu.citrix.com>

diff -r dbac9ee4d761 xen/arch/x86/mm/shadow/common.c
--- a/xen/arch/x86/mm/shadow/common.c	Mon Sep 08 16:02:13 2008 +0100
+++ b/xen/arch/x86/mm/shadow/common.c	Fri Sep 12 16:42:32 2008 +0100
@@ -2385,9 +2385,11 @@ int sh_remove_write_access(struct vcpu *
                           + ((fault_addr & VADDR_MASK) >> 27), 3); break;
             }

             /* 64bit Linux direct map at 0xffff810000000000; older kernels
              * had it at 0x0000010000000000UL */
             gfn = mfn_to_gfn(v->domain, gmfn);
+            GUESS(0xffff880000000000UL + (gfn << PAGE_SHIFT), 4);
             GUESS(0xffff810000000000UL + (gfn << PAGE_SHIFT), 4);
             GUESS(0x0000010000000000UL + (gfn << PAGE_SHIFT), 4);

^ permalink raw reply	[flat|nested] 7+ messages in thread

end of thread, other threads:[~2008-09-15 10:56 UTC | newest]

Thread overview: 7+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -2385,9 +2385,11 @@ int sh_remove_write_access(struct vcpu *
             }

-            /* 64bit Linux direct map at 0xffff810000000000; older kernels
-             * had it at 0x0000010000000000UL */
+            /* 64bit Linux direct map at 0xffff880000000000; older kernels
+             * had it at 0xffff880000000000, and older kernels yet had it
+             * at 0x0000010000000000UL */
             gfn = mfn_to_gfn(v->domain, gmfn);
2008-09-12 15:38 [PATCH] Add new location of Linux direct-map to the places to look for writable mappings George Dunlap
2008-09-12 15:57 ` Daniel Magenheimer
2008-09-12 19:19   ` [PATCH] Add new location of Linux direct-map to theplaces " Ian Pratt
2008-09-12 20:32     ` Gianluca Guida
2008-09-15  8:31     ` Tim Deegan
2008-09-15 10:56     ` George Dunlap
2008-09-12 23:49 ` [PATCH] Add new location of Linux direct-map to the places " Jeremy Fitzhardinge

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.